var Reflux = require('reflux');
var MarkdownEditorActions = require('../actions/MarkdownEditorActions');
var MarkdownSelectionActions = require('../actions/MarkdownSelectionActions');

var MarkdownEditorStore = Reflux.createStore({
  init: function() {
    this.currentSelection = null;
    this.listenTo(MarkdownEditorActions.makeBold, this.handleMakeBold);
    this.listenTo(MarkdownEditorActions.makeStrikethrough, this.handleMakeStrikethrough);
    this.listenTo(MarkdownEditorActions.makeItalic, this.handleMakeItalic);
    this.listenTo(MarkdownEditorActions.makeList, this.handleMakeList);
    this.listenTo(MarkdownEditorActions.makeUnderline, this.handleMakeUnderline);
    this.listenTo(MarkdownEditorActions.clearSelection, this.handleClearSelection);
    this.listenTo(MarkdownEditorActions.setSelection, this.handleSetSelection);
  },

  handleMakeBold: function() {
    this.trigger({action: 'bold', currentSelection: this.currentSelection});
  },

  handleMakeItalic: function() {
    this.trigger({action: 'italic', currentSelection: this.currentSelection});
  },

  handleMakeLink: function() {
    this.trigger({action: 'link', currentSelection: this.currentSelection});
  },

  handleMakeStrikethrough: function() {
    this.trigger({action: 'strikethrough', currentSelection: this.currentSelection});
  },

  handleMakeUnderline: function() {
    this.trigger({action: 'underline', currentSelection: this.currentSelection});
  },

  handleMakeList: function() {
    this.trigger({action: 'list', currentSelection: this.currentSelection});
  },


  handleClearSelection: function() {
    this.currentSelection = null;
    MarkdownSelectionActions.selectionCleared();
  },

  handleSetSelection: function(_selection) {
    this.currentSelection = _selection;
    MarkdownSelectionActions.selectionSet();
  }
});

module.exports = MarkdownEditorStore;
